pub struct CosmicCornerRadiusToplevelV1 { /* private fields */ }Available on crate feature
server only.Expand description
corner radius toplevel
The corner-radius object provides a way to specify a corner-radius for it’s associated toplevel.
If the xdg_toplevel associated with the cosmic_corner_radius_toplevel_v1 object has been destroyed, this object becomes inert. Any further requests other than destroy will raise the toplevel_destroyed protocol error.
See also the Request enum for this interface.